.. automodule:: stravalib.model
    :inherited-members: BaseModel

.. If you use both automodule and autosummary you duplicate autodocs efforts
.. Summary Functions
.. -------------------------------
.. .. autosummary::
..    :toctree: api/

..    lazy_property
..    check_valid_location
..    naive_datetime

.. Summary Classes
.. -------------------------------
.. .. autosummary::
..    :toctree: api/

..    DeprecatedSerializableMixin
..    BackwardCompatibilityMixin
..    BoundClientEntity
..    LatLon
..    Club
..    Gear
..    Bike
..    Shoe
..    ActivityTotals
..    AthleteStats
..    Athlete
..    ActivityComment
..    ActivityPhotoPrimary
..    ActivityPhotoMeta
..    ActivityPhoto
..    ActivityKudos
..    ActivityLap
..    Map
..    Split
..    SegmentExplorerResult
..    AthleteSegmentStats
..    AthletePrEffort
..    Segment
..    SegmentEffortAchievement
..    BaseEffort
..    BestEffort
..    SegmentEffort
..    Activity
..    DistributionBucket
..    BaseActivityZone
..    Stream
..    Route
..    Subscription
..    SubscriptionCallback
..    SubscriptionUpdate
